==> hoteldruid-mod-sv_3.0.3-1.tar.gz: sv/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":  				$messaggio = "Fil skapad"; break;
case "Non ho il permesso di scrittura sul file":	$messaggio = "Jag har inte skrivr&auml;ttigheter f&ouml;r filen"; break;
case "Si è verificato un errore cancellando il file":	$messaggio = "Det uppstod ett fel vid borttagning av filen"; break;
case "File cancellato":  			$messaggio = "Fil borttagen"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<b style=\"color: red;\">VARNING</b>: om du trycker p&aring; <b>\"<i>Forts&auml;tt</i>\"</b>, f&ouml;re data fr&aring;n <i>file</i> &aring;terst&auml;llts, kommer all data fr&aring;n <i>nuvarande databas</i> <b>tas bort</b>"; break;
case "Inserisci i nuovi dati per la connessione al database":	$messaggio = "L&auml;gg till ny data f&ouml;r att koppla till databasen"; break;
case "Tipo di database":  			$messaggio = "Databastyp"; break;
case "Nome del database da utilizzare":		$messaggio = "Namn p&aring; databasen som ska anv&auml;ndas"; break;
case "Database già esistente":  		$messaggio = "Existerande databas"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nej"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Om redan existerande och icketom, anv&auml;nd ett prefix som inte redan finns i databasen f&ouml;r tabellnamn"; break;
case "Nome del computer a cui collegarsi":	$messaggio = "Server"; break;
case "Numero della porta a cui collegarsi":	$messaggio = "Portnummer"; break;
case "Nome per l'autenticazione al database":	$messaggio = "Anv&auml;ndarnamn"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "L&ouml;senord"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Ladda det dynamiska biblitoeket \"pgsql.so\" eller \"mysql.so\""; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "v&auml;lj ja om det inte laddas automatiskt genom php"; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Namn p&aring; den tempor&auml;ra databasen"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "endast f&ouml;r Postgresql med icke-existerande databas"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":	$messaggio = "Gammal databas t&ouml;md, kan nu tas bort helt"; break;
case "Database creato":  			$messaggio = "Databas skapad"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":	$messaggio = "Det var inte m&ouml;jligt att koppla till den nya databasen. Kontrollera anslutningsdata, anv&auml;ndarprivilegier och namnet p&aring; databasen."; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":	$messaggio = "Det gick inte att skapa den nya databasen. Kontrollera anslutningsdata, anv&auml;ndarprivilegier, namnet p&aring; databasen och om det redan existerar en databas med namn"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Jag har inte skrivr&auml;ttigheter till dati-mappen"; break;
case "Non ho potuto leggere il file":  		$messaggio = "Jag kunde inte l&auml;sa filen"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Crea il file di backup":  		$messaggio = "Skapa backupfil"; break;
case "Crea un nuovo file di backup":  		$messaggio = "Skapa en ny backupfil"; break;
case "sovrascrivendo l'attuale":  		$messaggio = "skriver &ouml;ver nuvarande"; break;
case "Guarda il file":				$messaggio = "Se filen"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "f&ouml;r att spara den (anv&auml;nd troligen webbl&auml;sarens bak&aring;t-knapp f&ouml;r att komma tillbaks hit)"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case " l'attuale file di backup":  		$messaggio = " nuvarande backupfil"; break;
case "Ripristina i dati dal file":  		$messaggio = "&Aring;terst&auml;ll data fr&aring;n fil"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":	$messaggio = " (nuvarande data kommer tas bort), anv&auml;nds f&ouml;r databasskapande:"; break;
case "i dati dell'attuale connessione":  	$messaggio = "data f&ouml;r nuvarande koppling"; break;
case "nuovi dati":  				$messaggio = "ny data"; break;
case "Ho fatto l'upload del file":		$messaggio = "Du har uppladdat filen"; break;
case "Non ho potuto fare l'upload del file":	$messaggio = "Jag kunde inte ladda upp filen"; break;
case "Fai l'upload":  				$messaggio = "Ladda upp"; break;
case " del file di backup":  			$messaggio = " den h&auml;r backupfilen"; break;
case " di un nuovo file di backup":  		$messaggio = " den h&auml;r nya backupfilen"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix f&ouml;r tabellnamn"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "Prefixet f&ouml;r tabellnamnet &auml;r felaktigt (endast sm&aring; bokst&auml;ver, siffror och _ accepteras)"; break;
case "Il contenuto del file inviato non è corretto":	$messaggio = "Inneh&aring;llet i den s&auml;nda filen &auml;r felaktigt"; break;
case "Il formato del file è errato":  		$messaggio = "Filformatet &auml;r felaktigt"; break;
case "Compresso":  				$messaggio = "Komprimerat"; break;
case "Backup dei documenti":  			$messaggio = "Dokomentbackup"; break;
case "Crea il file di backup dei documenti":  	$messaggio = "Skapa dokument-backupfil"; break;
case "Crea un nuovo file di backup dei documenti":	$messaggio = "Skapa en ny dokument-backupfil"; break;
case " del file di backup dei documenti":	$messaggio = " det h&auml;r dokumentets backupfil"; break;
case " di un nuovo file di backup dei documenti":	$messaggio = " det h&auml;r nya dokumentets backupfil"; break;
case " l'attuale file di backup dei documenti":	$messaggio = " nuvarande dokuments backupfil"; break;
case "aggiungi ai documenti attuali":  		$messaggio = "l&auml;gg till till nuvarande dokument"; break;
case "rimpiazza i documenti attuali":  		$messaggio = "ers&auml;tt nuvarande dokument"; break;
case "i documenti attuali verranno cancellati":	$messaggio = "nuvarande dokument kommer tas bort"; break;
case "Ripristina i documenti dal file":  	$messaggio = "&Aring;terst&auml;ll dokument fr&aring;n fil"; break;
case "Documenti ripristinati":  		$messaggio = "Dokument &aring;terst&auml;llda"; break;
case "Backup completo":  			$messaggio = "Komplett backup"; break;
case "creato il":  				$messaggio = "skapad"; break;
case "alle":  					$messaggio = "vid"; break;
case "Backup":  				$messaggio = "Backup"; break;
case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
case "Includi le pagine per il sito web":  	$messaggio = "Include website pages"; break;
case "copia":  					$messaggio = "copy"; break;
case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
case "file copiato":  				$messaggio = "file copied"; break;
case "si è verificato un errore copiando il file":	$messaggio = "There was an error copying the file"; break;
case "Errori":  				$messaggio = "Errors"; break;
case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
case "solo il documento":  			$messaggio = "only document"; break;
case "Raggiunto il limite giornaliero di backup":	$messaggio = "You have reached the limit of daily backups"; break;
case "La versione attuale di HotelDruid e quella del file non coincidono":	$messaggio = "The current version of HotelDruid and the one of the file are not the same"; break;
case "La versione attuale e quella del file non coincidono":	$messaggio = "The current version and the one of the file are not the same"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.8-1.tar.gz: sv/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":  				$messaggio = "Fil skapad"; break;
case "Non ho il permesso di scrittura sul file":	$messaggio = "Jag har inte skrivr&auml;ttigheter f&ouml;r filen"; break;
case "Si è verificato un errore cancellando il file":	$messaggio = "Det uppstod ett fel vid borttagning av filen"; break;
case "File cancellato":  			$messaggio = "Fil borttagen"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<b style=\"color: red;\">VARNING</b>: om du trycker p&aring; <b>\"<i>Forts&auml;tt</i>\"</b>, f&ouml;re data fr&aring;n <i>file</i> &aring;terst&auml;llts, kommer all data fr&aring;n <i>nuvarande databas</i> <b>tas bort</b>"; break;
case "Inserisci i nuovi dati per la connessione al database":	$messaggio = "L&auml;gg till ny data f&ouml;r att koppla till databasen"; break;
case "Tipo di database":  			$messaggio = "Databastyp"; break;
case "Nome del database da utilizzare":		$messaggio = "Namn p&aring; databasen som ska anv&auml;ndas"; break;
case "Database già esistente":  		$messaggio = "Existerande databas"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nej"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Om redan existerande och icketom, anv&auml;nd ett prefix som inte redan finns i databasen f&ouml;r tabellnamn"; break;
case "Nome del computer a cui collegarsi":	$messaggio = "Server"; break;
case "Numero della porta a cui collegarsi":	$messaggio = "Portnummer"; break;
case "Nome per l'autenticazione al database":	$messaggio = "Anv&auml;ndarnamn"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "L&ouml;senord"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Ladda det dynamiska biblitoeket \"pgsql.so\" eller \"mysql.so\""; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "v&auml;lj ja om det inte laddas automatiskt genom php"; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Namn p&aring; den tempor&auml;ra databasen"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "endast f&ouml;r Postgresql med icke-existerande databas"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":	$messaggio = "Gammal databas t&ouml;md, kan nu tas bort helt"; break;
case "Database creato":  			$messaggio = "Databas skapad"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":	$messaggio = "Det var inte m&ouml;jligt att koppla till den nya databasen. Kontrollera anslutningsdata, anv&auml;ndarprivilegier och namnet p&aring; databasen."; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":	$messaggio = "Det gick inte att skapa den nya databasen. Kontrollera anslutningsdata, anv&auml;ndarprivilegier, namnet p&aring; databasen och om det redan existerar en databas med namn"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Jag har inte skrivr&auml;ttigheter till dati-mappen"; break;
case "Non ho potuto leggere il file":  		$messaggio = "Jag kunde inte l&auml;sa filen"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Crea il file di backup":  		$messaggio = "Skapa backupfil"; break;
case "Crea un nuovo file di backup":  		$messaggio = "Skapa en ny backupfil"; break;
case "sovrascrivendo l'attuale":  		$messaggio = "skriver &ouml;ver nuvarande"; break;
case "Guarda il file":				$messaggio = "Se filen"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "f&ouml;r att spara den (anv&auml;nd troligen webbl&auml;sarens bak&aring;t-knapp f&ouml;r att komma tillbaks hit)"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case " l'attuale file di backup":  		$messaggio = " nuvarande backupfil"; break;
case "Ripristina i dati dal file":  		$messaggio = "&Aring;terst&auml;ll data fr&aring;n fil"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":	$messaggio = " (nuvarande data kommer tas bort), anv&auml;nds f&ouml;r databasskapande:"; break;
case "i dati dell'attuale connessione":  	$messaggio = "data f&ouml;r nuvarande koppling"; break;
case "nuovi dati":  				$messaggio = "ny data"; break;
case "Ho fatto l'upload del file":		$messaggio = "Du har uppladdat filen"; break;
case "Non ho potuto fare l'upload del file":	$messaggio = "Jag kunde inte ladda upp filen"; break;
case "Fai l'upload":  				$messaggio = "Ladda upp"; break;
case " del file di backup":  			$messaggio = " den h&auml;r backupfilen"; break;
case " di un nuovo file di backup":  		$messaggio = " den h&auml;r nya backupfilen"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix f&ouml;r tabellnamn"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "Prefixet f&ouml;r tabellnamnet &auml;r felaktigt (endast sm&aring; bokst&auml;ver, siffror och _ accepteras)"; break;
case "Il contenuto del file inviato non è corretto":	$messaggio = "Inneh&aring;llet i den s&auml;nda filen &auml;r felaktigt"; break;
case "Il formato del file è errato":  		$messaggio = "Filformatet &auml;r felaktigt"; break;
case "Compresso":  				$messaggio = "Komprimerat"; break;
case "Backup dei documenti":  			$messaggio = "Dokomentbackup"; break;
case "Crea il file di backup dei documenti":  	$messaggio = "Skapa dokument-backupfil"; break;
case "Crea un nuovo file di backup dei documenti":	$messaggio = "Skapa en ny dokument-backupfil"; break;
case " del file di backup dei documenti":	$messaggio = " det h&auml;r dokumentets backupfil"; break;
case " di un nuovo file di backup dei documenti":	$messaggio = " det h&auml;r nya dokumentets backupfil"; break;
case " l'attuale file di backup dei documenti":	$messaggio = " nuvarande dokuments backupfil"; break;
case "aggiungi ai documenti attuali":  		$messaggio = "l&auml;gg till till nuvarande dokument"; break;
case "rimpiazza i documenti attuali":  		$messaggio = "ers&auml;tt nuvarande dokument"; break;
case "i documenti attuali verranno cancellati":	$messaggio = "nuvarande dokument kommer tas bort"; break;
case "Ripristina i documenti dal file":  	$messaggio = "&Aring;terst&auml;ll dokument fr&aring;n fil"; break;
case "Documenti ripristinati":  		$messaggio = "Dokument &aring;terst&auml;llda"; break;
case "Backup completo":  			$messaggio = "Komplett backup"; break;
case "creato il":  				$messaggio = "skapad"; break;
case "alle":  					$messaggio = "vid"; break;
case "Backup":  				$messaggio = "Backup"; break;
case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
case "La versione attuale di HotelDruid e quella del file non coincidono":	$messaggio = "The current version of HotelDruid and the one of the file are not the same"; break;
case "La versione attuale e quella del file non coincidono":	$messaggio = "The current version and the one of the file are not the same"; break;
case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
case "Includi le pagine per il sito web":  	$messaggio = "Include website pages"; break;
case "copia":  					$messaggio = "copy"; break;
case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
case "file copiato":  				$messaggio = "file copied"; break;
case "si è verificato un errore copiando il file":	$messaggio = "There was an error copying the file"; break;
case "Errori":  				$messaggio = "Errors"; break;
case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
case "solo il documento":  			$messaggio = "only document"; break;
case "Raggiunto il limite giornaliero di backup":	$messaggio = "You have reached the limit of daily backups"; break;
case "Il file di backup contiene più di":  	$messaggio = "The backup file contains more than"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
